# Generated by Django 3.2.15 on 2022-09-14 17:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('magic_notifier', '0002_auto_20220907_2112'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='subject',
            field=models.CharField(default='', max_length=255),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='notification',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='notifications'),
        ),
    ]
